=======
History
=======

0.1.0 (2018-05-20)
------------------

* First release on PyPI.

1.0.1 (2018-10-12)
------------------

* First production release


1.0.2 (2018-10-16)
------------------

* This patch allows the XMLBarcodeConversion step to also convert inbound
rule data as opposed to just the data within the context under a specific
key.

1.1.x
-----
The regular expression matching functionality of the BarcodeConverter
is now exported as a stand-alone function.
